# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/LoggingWidget.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_LoggingWidget(object):
    def setupUi(self, LoggingWidget):
        LoggingWidget.setObjectName("LoggingWidget")
        LoggingWidget.resize(562, 627)
        self.verticalLayout = QtWidgets.QVBoxLayout(LoggingWidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.te_logs = QtWidgets.QTextEdit(LoggingWidget)
        font = QtGui.QFont()
        font.setFamily("Monospace")
        font.setPointSize(10)
        self.te_logs.setFont(font)
        self.te_logs.setReadOnly(True)
        self.te_logs.setTabStopWidth(10)
        self.te_logs.setObjectName("te_logs")
        self.verticalLayout.addWidget(self.te_logs)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.label_2 = QtWidgets.QLabel(LoggingWidget)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.cb_log_level = QtWidgets.QComboBox(LoggingWidget)
        self.cb_log_level.setToolTip("")
        self.cb_log_level.setObjectName("cb_log_level")
        self.cb_log_level.addItem("")
        self.cb_log_level.addItem("")
        self.cb_log_level.addItem("")
        self.cb_log_level.addItem("")
        self.horizontalLayout_2.addWidget(self.cb_log_level)
        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(LoggingWidget)
        self.cb_log_level.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(LoggingWidget)

    def retranslateUi(self, LoggingWidget):
        _translate = QtCore.QCoreApplication.translate
        LoggingWidget.setWindowTitle(_translate("LoggingWidget", "Form"))
        self.label_2.setText(_translate("LoggingWidget", "Log level:"))
        self.cb_log_level.setItemText(0, _translate("LoggingWidget", "Debug"))
        self.cb_log_level.setItemText(1, _translate("LoggingWidget", "Info"))
        self.cb_log_level.setItemText(2, _translate("LoggingWidget", "Warning"))
        self.cb_log_level.setItemText(3, _translate("LoggingWidget", "Error"))

