# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/SaveSnapshotDialog.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_SaveSnapshotDialog(object):
    def setupUi(self, SaveSnapshotDialog):
        SaveSnapshotDialog.setObjectName("SaveSnapshotDialog")
        SaveSnapshotDialog.resize(569, 574)
        self.verticalLayout = QtWidgets.QVBoxLayout(SaveSnapshotDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtWidgets.QLabel(SaveSnapshotDialog)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        self.leSnapshotName = QtWidgets.QLineEdit(SaveSnapshotDialog)
        self.leSnapshotName.setMinimumSize(QtCore.QSize(200, 0))
        self.leSnapshotName.setObjectName("leSnapshotName")
        self.horizontalLayout_2.addWidget(self.leSnapshotName)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.btnSelectAll = QtWidgets.QToolButton(SaveSnapshotDialog)
        self.btnSelectAll.setCheckable(False)
        self.btnSelectAll.setObjectName("btnSelectAll")
        self.horizontalLayout_2.addWidget(self.btnSelectAll)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.chbShowAllMotors = QtWidgets.QCheckBox(SaveSnapshotDialog)
        self.chbShowAllMotors.setObjectName("chbShowAllMotors")
        self.horizontalLayout_2.addWidget(self.chbShowAllMotors)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.twDevices = QtWidgets.QTableWidget(SaveSnapshotDialog)
        self.twDevices.setAlternatingRowColors(True)
        self.twDevices.setObjectName("twDevices")
        self.twDevices.setColumnCount(0)
        self.twDevices.setRowCount(0)
        self.verticalLayout.addWidget(self.twDevices)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem2)
        self.btnSaveSnapshot = QtWidgets.QPushButton(SaveSnapshotDialog)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSaveSnapshot.setIcon(icon)
        self.btnSaveSnapshot.setIconSize(QtCore.QSize(12, 12))
        self.btnSaveSnapshot.setObjectName("btnSaveSnapshot")
        self.horizontalLayout.addWidget(self.btnSaveSnapshot)
        self.btnCancel = QtWidgets.QPushButton(SaveSnapshotDialog)
        self.btnCancel.setObjectName("btnCancel")
        self.horizontalLayout.addWidget(self.btnCancel)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(SaveSnapshotDialog)
        self.btnCancel.clicked.connect(SaveSnapshotDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(SaveSnapshotDialog)
        SaveSnapshotDialog.setTabOrder(self.btnSaveSnapshot, self.btnCancel)

    def retranslateUi(self, SaveSnapshotDialog):
        _translate = QtCore.QCoreApplication.translate
        SaveSnapshotDialog.setWindowTitle(_translate("SaveSnapshotDialog", "Save Beamline Snapshot"))
        self.label.setText(_translate("SaveSnapshotDialog", "Name:"))
        self.btnSelectAll.setToolTip(_translate("SaveSnapshotDialog", "Select All Motors"))
        self.btnSelectAll.setText(_translate("SaveSnapshotDialog", "Select All"))
        self.chbShowAllMotors.setText(_translate("SaveSnapshotDialog", "show all motors"))
        self.btnSaveSnapshot.setText(_translate("SaveSnapshotDialog", "Save"))
        self.btnCancel.setText(_translate("SaveSnapshotDialog", "Cancel"))

import beamline_console.gui.icons_rc
