# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/BeamlineWidget.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_BeamlineWidget(object):
    def setupUi(self, BeamlineWidget):
        BeamlineWidget.setObjectName("BeamlineWidget")
        BeamlineWidget.resize(750, 676)
        BeamlineWidget.setMinimumSize(QtCore.QSize(750, 0))
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(BeamlineWidget)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.fr_device_selector = QtWidgets.QFrame(BeamlineWidget)
        self.fr_device_selector.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.fr_device_selector.setFrameShadow(QtWidgets.QFrame.Raised)
        self.fr_device_selector.setObjectName("fr_device_selector")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.fr_device_selector)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.but_show_selector = QtWidgets.QPushButton(self.fr_device_selector)
        font = QtGui.QFont()
        font.setPointSize(15)
        self.but_show_selector.setFont(font)
        self.but_show_selector.setCheckable(True)
        self.but_show_selector.setChecked(True)
        self.but_show_selector.setObjectName("but_show_selector")
        self.verticalLayout.addWidget(self.but_show_selector)
        self.beamline_view = QtWidgets.QGraphicsView(self.fr_device_selector)
        self.beamline_view.setMinimumSize(QtCore.QSize(0, 100))
        self.beamline_view.setMaximumSize(QtCore.QSize(16777215, 1000))
        self.beamline_view.setObjectName("beamline_view")
        self.verticalLayout.addWidget(self.beamline_view)
        self.verticalLayout_2.addWidget(self.fr_device_selector)
        self.device_widget = DeviceWidget(BeamlineWidget)
        self.device_widget.setObjectName("device_widget")
        self.verticalLayout_2.addWidget(self.device_widget)
        self.verticalLayout_2.setStretch(1, 1)

        self.retranslateUi(BeamlineWidget)
        QtCore.QMetaObject.connectSlotsByName(BeamlineWidget)

    def retranslateUi(self, BeamlineWidget):
        _translate = QtCore.QCoreApplication.translate
        BeamlineWidget.setWindowTitle(_translate("BeamlineWidget", "BeamlineWidget"))
        self.but_show_selector.setText(_translate("BeamlineWidget", "Show device selector"))

from beamline_console.devicecontrol.devicewidget import DeviceWidget
