# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/ErrorDialog.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_ErrorDialog(object):
    def setupUi(self, ErrorDialog):
        ErrorDialog.setObjectName("ErrorDialog")
        ErrorDialog.resize(950, 327)
        self.verticalLayout = QtWidgets.QVBoxLayout(ErrorDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.teDetails = QtWidgets.QTextEdit(ErrorDialog)
        self.teDetails.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.teDetails.sizePolicy().hasHeightForWidth())
        self.teDetails.setSizePolicy(sizePolicy)
        self.teDetails.setReadOnly(True)
        self.teDetails.setObjectName("teDetails")
        self.verticalLayout.addWidget(self.teDetails)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.tbOk = QtWidgets.QToolButton(ErrorDialog)
        self.tbOk.setObjectName("tbOk")
        self.horizontalLayout_2.addWidget(self.tbOk)
        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(ErrorDialog)
        self.tbOk.clicked.connect(ErrorDialog.accept)
        QtCore.QMetaObject.connectSlotsByName(ErrorDialog)

    def retranslateUi(self, ErrorDialog):
        _translate = QtCore.QCoreApplication.translate
        ErrorDialog.setWindowTitle(_translate("ErrorDialog", "Experimental Control Error"))
        self.tbOk.setText(_translate("ErrorDialog", "OK"))

