# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/InputDialog.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_InputDialog(object):
    def setupUi(self, InputDialog):
        InputDialog.setObjectName("InputDialog")
        InputDialog.resize(700, 700)
        InputDialog.setMinimumSize(QtCore.QSize(700, 700))
        InputDialog.setMaximumSize(QtCore.QSize(700, 700))
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(InputDialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lb_titel = QtWidgets.QLabel(InputDialog)
        font = QtGui.QFont()
        font.setPointSize(20)
        font.setBold(True)
        font.setWeight(75)
        self.lb_titel.setFont(font)
        self.lb_titel.setAlignment(QtCore.Qt.AlignCenter)
        self.lb_titel.setObjectName("lb_titel")
        self.verticalLayout.addWidget(self.lb_titel)
        self.lb_number = QtWidgets.QLabel(InputDialog)
        font = QtGui.QFont()
        font.setPointSize(20)
        font.setBold(True)
        font.setWeight(75)
        self.lb_number.setFont(font)
        self.lb_number.setAlignment(QtCore.Qt.AlignCenter)
        self.lb_number.setObjectName("lb_number")
        self.verticalLayout.addWidget(self.lb_number)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setSpacing(20)
        self.gridLayout.setObjectName("gridLayout")
        self.but_1 = QtWidgets.QPushButton(InputDialog)
        self.but_1.setMinimumSize(QtCore.QSize(100, 100))
        self.but_1.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_1.setFont(font)
        self.but_1.setObjectName("but_1")
        self.gridLayout.addWidget(self.but_1, 0, 0, 1, 1)
        self.but_2 = QtWidgets.QPushButton(InputDialog)
        self.but_2.setMinimumSize(QtCore.QSize(100, 100))
        self.but_2.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_2.setFont(font)
        self.but_2.setObjectName("but_2")
        self.gridLayout.addWidget(self.but_2, 0, 1, 1, 1)
        self.but_3 = QtWidgets.QPushButton(InputDialog)
        self.but_3.setMinimumSize(QtCore.QSize(100, 100))
        self.but_3.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_3.setFont(font)
        self.but_3.setObjectName("but_3")
        self.gridLayout.addWidget(self.but_3, 0, 2, 1, 1)
        self.but_4 = QtWidgets.QPushButton(InputDialog)
        self.but_4.setMinimumSize(QtCore.QSize(100, 100))
        self.but_4.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_4.setFont(font)
        self.but_4.setObjectName("but_4")
        self.gridLayout.addWidget(self.but_4, 1, 0, 1, 1)
        self.but_5 = QtWidgets.QPushButton(InputDialog)
        self.but_5.setMinimumSize(QtCore.QSize(100, 100))
        self.but_5.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_5.setFont(font)
        self.but_5.setObjectName("but_5")
        self.gridLayout.addWidget(self.but_5, 1, 1, 1, 1)
        self.but_6 = QtWidgets.QPushButton(InputDialog)
        self.but_6.setMinimumSize(QtCore.QSize(100, 100))
        self.but_6.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_6.setFont(font)
        self.but_6.setObjectName("but_6")
        self.gridLayout.addWidget(self.but_6, 1, 2, 1, 1)
        self.but_7 = QtWidgets.QPushButton(InputDialog)
        self.but_7.setMinimumSize(QtCore.QSize(100, 100))
        self.but_7.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_7.setFont(font)
        self.but_7.setObjectName("but_7")
        self.gridLayout.addWidget(self.but_7, 2, 0, 1, 1)
        self.but_8 = QtWidgets.QPushButton(InputDialog)
        self.but_8.setMinimumSize(QtCore.QSize(100, 100))
        self.but_8.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_8.setFont(font)
        self.but_8.setObjectName("but_8")
        self.gridLayout.addWidget(self.but_8, 2, 1, 1, 1)
        self.but_9 = QtWidgets.QPushButton(InputDialog)
        self.but_9.setMinimumSize(QtCore.QSize(100, 100))
        self.but_9.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_9.setFont(font)
        self.but_9.setObjectName("but_9")
        self.gridLayout.addWidget(self.but_9, 2, 2, 1, 1)
        self.but_0 = QtWidgets.QPushButton(InputDialog)
        self.but_0.setMinimumSize(QtCore.QSize(100, 100))
        self.but_0.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_0.setFont(font)
        self.but_0.setObjectName("but_0")
        self.gridLayout.addWidget(self.but_0, 3, 1, 1, 1)
        self.but_punkt = QtWidgets.QPushButton(InputDialog)
        self.but_punkt.setMinimumSize(QtCore.QSize(100, 100))
        self.but_punkt.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_punkt.setFont(font)
        self.but_punkt.setObjectName("but_punkt")
        self.gridLayout.addWidget(self.but_punkt, 3, 0, 1, 1)
        self.but_sign = QtWidgets.QPushButton(InputDialog)
        self.but_sign.setMinimumSize(QtCore.QSize(100, 100))
        self.but_sign.setMaximumSize(QtCore.QSize(100, 100))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_sign.setFont(font)
        self.but_sign.setObjectName("but_sign")
        self.gridLayout.addWidget(self.but_sign, 3, 2, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout)
        self.but_box = QtWidgets.QDialogButtonBox(InputDialog)
        font = QtGui.QFont()
        font.setPointSize(20)
        self.but_box.setFont(font)
        self.but_box.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok|QtWidgets.QDialogButtonBox.Reset)
        self.but_box.setCenterButtons(False)
        self.but_box.setObjectName("but_box")
        self.verticalLayout_2.addWidget(self.but_box)

        self.retranslateUi(InputDialog)
        QtCore.QMetaObject.connectSlotsByName(InputDialog)

    def retranslateUi(self, InputDialog):
        _translate = QtCore.QCoreApplication.translate
        InputDialog.setWindowTitle(_translate("InputDialog", "Experiment Control"))
        self.lb_titel.setText(_translate("InputDialog", "Enter superuser pin"))
        self.lb_number.setText(_translate("InputDialog", "*****"))
        self.but_1.setText(_translate("InputDialog", "1"))
        self.but_2.setText(_translate("InputDialog", "2"))
        self.but_3.setText(_translate("InputDialog", "3"))
        self.but_4.setText(_translate("InputDialog", "4"))
        self.but_5.setText(_translate("InputDialog", "5"))
        self.but_6.setText(_translate("InputDialog", "6"))
        self.but_7.setText(_translate("InputDialog", "7"))
        self.but_8.setText(_translate("InputDialog", "8"))
        self.but_9.setText(_translate("InputDialog", "9"))
        self.but_0.setText(_translate("InputDialog", "0"))
        self.but_punkt.setText(_translate("InputDialog", ","))
        self.but_sign.setText(_translate("InputDialog", "+/-"))

