# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/MotorPropsDialog.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MotorPropsDialog(object):
    def setupUi(self, MotorPropsDialog):
        MotorPropsDialog.setObjectName("MotorPropsDialog")
        MotorPropsDialog.resize(605, 634)
        MotorPropsDialog.setMaximumSize(QtCore.QSize(20000, 20000))
        self.verticalLayout = QtWidgets.QVBoxLayout(MotorPropsDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_7 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_7.setObjectName("label_7")
        self.gridLayout_3.addWidget(self.label_7, 0, 0, 1, 1)
        self.lbMotorName = QtWidgets.QLabel(MotorPropsDialog)
        self.lbMotorName.setMinimumSize(QtCore.QSize(200, 0))
        self.lbMotorName.setStyleSheet("color: rgb(0, 65, 136);")
        self.lbMotorName.setObjectName("lbMotorName")
        self.gridLayout_3.addWidget(self.lbMotorName, 0, 1, 1, 1)
        self.label_8 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_8.setObjectName("label_8")
        self.gridLayout_3.addWidget(self.label_8, 1, 0, 1, 1)
        self.lbTangoServer = QtWidgets.QLabel(MotorPropsDialog)
        self.lbTangoServer.setMinimumSize(QtCore.QSize(200, 0))
        self.lbTangoServer.setStyleSheet("color: rgb(0, 65, 136);")
        self.lbTangoServer.setObjectName("lbTangoServer")
        self.gridLayout_3.addWidget(self.lbTangoServer, 1, 1, 1, 1)
        self.horizontalLayout_4.addLayout(self.gridLayout_3)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.line_2 = QtWidgets.QFrame(MotorPropsDialog)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.verticalLayout.addWidget(self.line_2)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.leBacklash = QtWidgets.QLineEdit(MotorPropsDialog)
        self.leBacklash.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.leBacklash.setMaxLength(20)
        self.leBacklash.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leBacklash.setObjectName("leBacklash")
        self.gridLayout.addWidget(self.leBacklash, 5, 1, 1, 1)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_3 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_9.addWidget(self.label_3)
        self.label_6 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_6.setStyleSheet("color: rgb(124, 120, 120);")
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_9.addWidget(self.label_6)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem1)
        self.gridLayout.addLayout(self.horizontalLayout_9, 4, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label = QtWidgets.QLabel(MotorPropsDialog)
        self.label.setObjectName("label")
        self.horizontalLayout_3.addWidget(self.label)
        self.label_15 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_15.setStyleSheet("color: rgb(124, 120, 120);")
        self.label_15.setObjectName("label_15")
        self.horizontalLayout_3.addWidget(self.label_15)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.gridLayout.addLayout(self.horizontalLayout_3, 1, 0, 1, 1)
        self.leSlewRate = QtWidgets.QLineEdit(MotorPropsDialog)
        self.leSlewRate.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.leSlewRate.setMaxLength(20)
        self.leSlewRate.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leSlewRate.setObjectName("leSlewRate")
        self.gridLayout.addWidget(self.leSlewRate, 3, 1, 1, 1)
        self.leAcceleration = QtWidgets.QLineEdit(MotorPropsDialog)
        self.leAcceleration.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.leAcceleration.setMaxLength(20)
        self.leAcceleration.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leAcceleration.setObjectName("leAcceleration")
        self.gridLayout.addWidget(self.leAcceleration, 4, 1, 1, 1)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_2 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_8.addWidget(self.label_2)
        self.label_14 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_14.setStyleSheet("color: rgb(124, 120, 120);")
        self.label_14.setObjectName("label_14")
        self.horizontalLayout_8.addWidget(self.label_14)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem3)
        self.gridLayout.addLayout(self.horizontalLayout_8, 3, 0, 1, 1)
        self.btnCalibrate = QtWidgets.QPushButton(MotorPropsDialog)
        self.btnCalibrate.setMaximumSize(QtCore.QSize(16777215, 28))
        self.btnCalibrate.setIconSize(QtCore.QSize(24, 18))
        self.btnCalibrate.setObjectName("btnCalibrate")
        self.gridLayout.addWidget(self.btnCalibrate, 0, 2, 1, 1)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.label_4 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_10.addWidget(self.label_4)
        self.label_13 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_13.setStyleSheet("color: rgb(124, 120, 120);")
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_10.addWidget(self.label_13)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem4)
        self.gridLayout.addLayout(self.horizontalLayout_10, 5, 0, 1, 1)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_9 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_7.addWidget(self.label_9)
        self.label_16 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_16.setStyleSheet("color: rgb(124, 120, 120);")
        self.label_16.setObjectName("label_16")
        self.horizontalLayout_7.addWidget(self.label_16)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem5)
        self.gridLayout.addLayout(self.horizontalLayout_7, 0, 0, 1, 1)
        self.leConversion = QtWidgets.QLineEdit(MotorPropsDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.leConversion.sizePolicy().hasHeightForWidth())
        self.leConversion.setSizePolicy(sizePolicy)
        self.leConversion.setMinimumSize(QtCore.QSize(150, 0))
        self.leConversion.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.leConversion.setMaxLength(20)
        self.leConversion.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leConversion.setObjectName("leConversion")
        self.gridLayout.addWidget(self.leConversion, 1, 1, 1, 1)
        self.leCalibration = QtWidgets.QLineEdit(MotorPropsDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.leCalibration.sizePolicy().hasHeightForWidth())
        self.leCalibration.setSizePolicy(sizePolicy)
        self.leCalibration.setMinimumSize(QtCore.QSize(220, 0))
        self.leCalibration.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.leCalibration.setMaxLength(20)
        self.leCalibration.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leCalibration.setObjectName("leCalibration")
        self.gridLayout.addWidget(self.leCalibration, 0, 1, 1, 1)
        self.leBaseRate = QtWidgets.QLineEdit(MotorPropsDialog)
        self.leBaseRate.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.leBaseRate.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leBaseRate.setObjectName("leBaseRate")
        self.gridLayout.addWidget(self.leBaseRate, 6, 1, 1, 1)
        self.label_21 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_21.setObjectName("label_21")
        self.gridLayout.addWidget(self.label_21, 6, 0, 1, 1)
        self.horizontalLayout_11.addLayout(self.gridLayout)
        self.verticalLayout.addLayout(self.horizontalLayout_11)
        self.chbUserLimits = QtWidgets.QCheckBox(MotorPropsDialog)
        self.chbUserLimits.setObjectName("chbUserLimits")
        self.verticalLayout.addWidget(self.chbUserLimits)
        self.frameUserLimits = QtWidgets.QFrame(MotorPropsDialog)
        self.frameUserLimits.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frameUserLimits.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frameUserLimits.setLineWidth(0)
        self.frameUserLimits.setObjectName("frameUserLimits")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.frameUserLimits)
        self.gridLayout_4.setContentsMargins(-1, 0, -1, 0)
        self.gridLayout_4.setHorizontalSpacing(6)
        self.gridLayout_4.setObjectName("gridLayout_4")
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem6, 0, 4, 1, 1)
        self.leHighLimitUser = QtWidgets.QLineEdit(self.frameUserLimits)
        self.leHighLimitUser.setMaximumSize(QtCore.QSize(140, 16777215))
        self.leHighLimitUser.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leHighLimitUser.setObjectName("leHighLimitUser")
        self.gridLayout_4.addWidget(self.leHighLimitUser, 1, 3, 1, 1)
        self.leLowLimitUser = QtWidgets.QLineEdit(self.frameUserLimits)
        self.leLowLimitUser.setMaximumSize(QtCore.QSize(140, 16777215))
        self.leLowLimitUser.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leLowLimitUser.setObjectName("leLowLimitUser")
        self.gridLayout_4.addWidget(self.leLowLimitUser, 0, 3, 1, 1)
        self.label_20 = QtWidgets.QLabel(self.frameUserLimits)
        self.label_20.setObjectName("label_20")
        self.gridLayout_4.addWidget(self.label_20, 1, 1, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.frameUserLimits)
        self.label_17.setObjectName("label_17")
        self.gridLayout_4.addWidget(self.label_17, 0, 1, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.frameUserLimits)
        self.label_18.setStyleSheet("color: rgb(124, 120, 120);")
        self.label_18.setObjectName("label_18")
        self.gridLayout_4.addWidget(self.label_18, 0, 2, 1, 1)
        self.label_19 = QtWidgets.QLabel(self.frameUserLimits)
        self.label_19.setStyleSheet("color: rgb(124, 120, 120);")
        self.label_19.setObjectName("label_19")
        self.gridLayout_4.addWidget(self.label_19, 1, 2, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem7, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.frameUserLimits)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_11 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_11.setObjectName("label_11")
        self.gridLayout_2.addWidget(self.label_11, 1, 0, 1, 1)
        self.label_12 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_12.setStyleSheet("color: rgb(124, 120, 120);")
        self.label_12.setObjectName("label_12")
        self.gridLayout_2.addWidget(self.label_12, 1, 1, 1, 1)
        self.leHighLimit = QtWidgets.QLineEdit(MotorPropsDialog)
        self.leHighLimit.setMaximumSize(QtCore.QSize(140, 16777215))
        self.leHighLimit.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leHighLimit.setObjectName("leHighLimit")
        self.gridLayout_2.addWidget(self.leHighLimit, 1, 2, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem8, 0, 3, 1, 1)
        self.label_10 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_10.setStyleSheet("color: rgb(124, 120, 120);")
        self.label_10.setObjectName("label_10")
        self.gridLayout_2.addWidget(self.label_10, 0, 1, 1, 1)
        self.label_5 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 0, 0, 1, 1)
        self.leLowLimit = QtWidgets.QLineEdit(MotorPropsDialog)
        self.leLowLimit.setMaximumSize(QtCore.QSize(140, 16777215))
        self.leLowLimit.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leLowLimit.setObjectName("leLowLimit")
        self.gridLayout_2.addWidget(self.leLowLimit, 0, 2, 1, 1)
        self.label_22 = QtWidgets.QLabel(MotorPropsDialog)
        self.label_22.setObjectName("label_22")
        self.gridLayout_2.addWidget(self.label_22, 2, 0, 1, 1)
        self.leDecimals = QtWidgets.QLineEdit(MotorPropsDialog)
        self.leDecimals.setMaximumSize(QtCore.QSize(140, 16777215))
        self.leDecimals.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.leDecimals.setReadOnly(False)
        self.leDecimals.setObjectName("leDecimals")
        self.gridLayout_2.addWidget(self.leDecimals, 2, 2, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_2)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem9)
        self.btnAllParams = QtWidgets.QToolButton(MotorPropsDialog)
        self.btnAllParams.setObjectName("btnAllParams")
        self.verticalLayout.addWidget(self.btnAllParams)
        self.line_3 = QtWidgets.QFrame(MotorPropsDialog)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.verticalLayout.addWidget(self.line_3)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btnUndo = QtWidgets.QPushButton(MotorPropsDialog)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/revert.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnUndo.setIcon(icon)
        self.btnUndo.setIconSize(QtCore.QSize(12, 12))
        self.btnUndo.setObjectName("btnUndo")
        self.horizontalLayout.addWidget(self.btnUndo)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem10)
        self.btnSaveProps = QtWidgets.QPushButton(MotorPropsDialog)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSaveProps.setIcon(icon1)
        self.btnSaveProps.setIconSize(QtCore.QSize(12, 12))
        self.btnSaveProps.setObjectName("btnSaveProps")
        self.horizontalLayout.addWidget(self.btnSaveProps)
        self.btnCancel = QtWidgets.QPushButton(MotorPropsDialog)
        self.btnCancel.setObjectName("btnCancel")
        self.horizontalLayout.addWidget(self.btnCancel)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(MotorPropsDialog)
        self.btnCancel.clicked.connect(MotorPropsDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(MotorPropsDialog)
        MotorPropsDialog.setTabOrder(self.leCalibration, self.leConversion)
        MotorPropsDialog.setTabOrder(self.leConversion, self.leSlewRate)
        MotorPropsDialog.setTabOrder(self.leSlewRate, self.leAcceleration)
        MotorPropsDialog.setTabOrder(self.leAcceleration, self.leBacklash)
        MotorPropsDialog.setTabOrder(self.leBacklash, self.leLowLimit)
        MotorPropsDialog.setTabOrder(self.leLowLimit, self.leHighLimit)
        MotorPropsDialog.setTabOrder(self.leHighLimit, self.btnUndo)
        MotorPropsDialog.setTabOrder(self.btnUndo, self.btnSaveProps)
        MotorPropsDialog.setTabOrder(self.btnSaveProps, self.btnCancel)
        MotorPropsDialog.setTabOrder(self.btnCancel, self.btnCalibrate)

    def retranslateUi(self, MotorPropsDialog):
        _translate = QtCore.QCoreApplication.translate
        MotorPropsDialog.setWindowTitle(_translate("MotorPropsDialog", "Motor Properties"))
        self.label_7.setText(_translate("MotorPropsDialog", "Alias:"))
        self.lbMotorName.setText(_translate("MotorPropsDialog", "None"))
        self.label_8.setText(_translate("MotorPropsDialog", "Server: "))
        self.lbTangoServer.setText(_translate("MotorPropsDialog", "None"))
        self.leBacklash.setText(_translate("MotorPropsDialog", "0"))
        self.label_3.setText(_translate("MotorPropsDialog", "Acceleration"))
        self.label_6.setText(_translate("MotorPropsDialog", "[step/sec^2]:"))
        self.label.setText(_translate("MotorPropsDialog", "Conversion"))
        self.label_15.setText(_translate("MotorPropsDialog", "[step/unit]:"))
        self.leSlewRate.setText(_translate("MotorPropsDialog", "0"))
        self.leAcceleration.setText(_translate("MotorPropsDialog", "0"))
        self.label_2.setText(_translate("MotorPropsDialog", "Slew rate"))
        self.label_14.setText(_translate("MotorPropsDialog", "[step/sec]:"))
        self.btnCalibrate.setText(_translate("MotorPropsDialog", "Calibrate"))
        self.label_4.setText(_translate("MotorPropsDialog", "Backlash"))
        self.label_13.setText(_translate("MotorPropsDialog", "[step]:"))
        self.label_9.setText(_translate("MotorPropsDialog", "Calibration"))
        self.label_16.setText(_translate("MotorPropsDialog", "[unit]:"))
        self.leConversion.setText(_translate("MotorPropsDialog", "0.00"))
        self.leCalibration.setText(_translate("MotorPropsDialog", "0.00"))
        self.leBaseRate.setText(_translate("MotorPropsDialog", "0"))
        self.label_21.setText(_translate("MotorPropsDialog", "Base rate:"))
        self.chbUserLimits.setText(_translate("MotorPropsDialog", "user limits"))
        self.label_20.setText(_translate("MotorPropsDialog", "High limit"))
        self.label_17.setText(_translate("MotorPropsDialog", "Low limit"))
        self.label_18.setText(_translate("MotorPropsDialog", "[unit]:"))
        self.label_19.setText(_translate("MotorPropsDialog", "[unit]:"))
        self.label_11.setText(_translate("MotorPropsDialog", "High limit"))
        self.label_12.setText(_translate("MotorPropsDialog", "[unit]:"))
        self.leHighLimit.setText(_translate("MotorPropsDialog", "0.00"))
        self.label_10.setText(_translate("MotorPropsDialog", "[unit]:"))
        self.label_5.setText(_translate("MotorPropsDialog", "Low limit"))
        self.leLowLimit.setText(_translate("MotorPropsDialog", "0.00"))
        self.label_22.setText(_translate("MotorPropsDialog", "Decimals"))
        self.leDecimals.setText(_translate("MotorPropsDialog", "3"))
        self.btnAllParams.setToolTip(_translate("MotorPropsDialog", "Edit other parameters"))
        self.btnAllParams.setText(_translate("MotorPropsDialog", "All Properties..."))
        self.btnUndo.setText(_translate("MotorPropsDialog", "Undo"))
        self.btnSaveProps.setText(_translate("MotorPropsDialog", "Save"))
        self.btnCancel.setText(_translate("MotorPropsDialog", "Cancel"))

import beamline_console.gui.icons_rc
