# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/DeviceWidget.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_DeviceWidget(object):
    def setupUi(self, DeviceWidget):
        DeviceWidget.setObjectName("DeviceWidget")
        DeviceWidget.resize(761, 374)
        self.verticalLayout = QtWidgets.QVBoxLayout(DeviceWidget)
        self.verticalLayout.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.but_save = QtWidgets.QToolButton(DeviceWidget)
        self.but_save.setMinimumSize(QtCore.QSize(80, 80))
        self.but_save.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.but_save.setIcon(icon)
        self.but_save.setIconSize(QtCore.QSize(50, 50))
        self.but_save.setObjectName("but_save")
        self.horizontalLayout.addWidget(self.but_save)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.but_stop = QtWidgets.QPushButton(DeviceWidget)
        self.but_stop.setMinimumSize(QtCore.QSize(250, 80))
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.but_stop.setFont(font)
        self.but_stop.setStyleSheet("color: rgb(255, 0, 0);")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/stop_red.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.but_stop.setIcon(icon1)
        self.but_stop.setIconSize(QtCore.QSize(12, 12))
        self.but_stop.setObjectName("but_stop")
        self.horizontalLayout.addWidget(self.but_stop)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.scrollArea = QtWidgets.QScrollArea(DeviceWidget)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 755, 280))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.wi_device_container = QtWidgets.QWidget(self.scrollAreaWidgetContents)
        self.wi_device_container.setObjectName("wi_device_container")
        self.verticalLayout_2.addWidget(self.wi_device_container)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout.addWidget(self.scrollArea)
        self.verticalLayout.setStretch(1, 1)

        self.retranslateUi(DeviceWidget)
        QtCore.QMetaObject.connectSlotsByName(DeviceWidget)

    def retranslateUi(self, DeviceWidget):
        _translate = QtCore.QCoreApplication.translate
        DeviceWidget.setWindowTitle(_translate("DeviceWidget", "Form"))
        self.but_save.setToolTip(_translate("DeviceWidget", "Save Beamline Snapshot"))
        self.but_stop.setToolTip(_translate("DeviceWidget", "Stop All Motors"))
        self.but_stop.setText(_translate("DeviceWidget", "STOP"))

import beamline_console.gui.icons_rc
