# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/DeviceItem.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_DeviceItem(object):
    def setupUi(self, DeviceItem):
        DeviceItem.setObjectName("DeviceItem")
        DeviceItem.resize(188, 146)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(DeviceItem.sizePolicy().hasHeightForWidth())
        DeviceItem.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(DeviceItem)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.tbStatus = QtWidgets.QToolButton(DeviceItem)
        self.tbStatus.setMaximumSize(QtCore.QSize(18, 12))
        self.tbStatus.setText("")
        self.tbStatus.setObjectName("tbStatus")
        self.horizontalLayout_2.addWidget(self.tbStatus)
        self.lbName = ClickableLabel(DeviceItem)
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.lbName.setFont(font)
        self.lbName.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbName.setObjectName("lbName")
        self.horizontalLayout_2.addWidget(self.lbName)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.lbImage = DeviceImage(DeviceItem)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lbImage.sizePolicy().hasHeightForWidth())
        self.lbImage.setSizePolicy(sizePolicy)
        self.lbImage.setMinimumSize(QtCore.QSize(0, 75))
        self.lbImage.setFrameShape(QtWidgets.QFrame.Box)
        self.lbImage.setFrameShadow(QtWidgets.QFrame.Plain)
        self.lbImage.setLineWidth(1)
        self.lbImage.setText("")
        self.lbImage.setAlignment(QtCore.Qt.AlignCenter)
        self.lbImage.setObjectName("lbImage")
        self.verticalLayout.addWidget(self.lbImage)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.tbLogs = QtWidgets.QToolButton(DeviceItem)
        self.tbLogs.setMinimumSize(QtCore.QSize(0, 0))
        self.tbLogs.setMaximumSize(QtCore.QSize(16777215, 18))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/page.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tbLogs.setIcon(icon)
        self.tbLogs.setIconSize(QtCore.QSize(12, 12))
        self.tbLogs.setObjectName("tbLogs")
        self.horizontalLayout.addWidget(self.tbLogs)
        self.tbCameras = QtWidgets.QToolButton(DeviceItem)
        self.tbCameras.setMaximumSize(QtCore.QSize(16777215, 18))
        self.tbCameras.setObjectName("tbCameras")
        self.horizontalLayout.addWidget(self.tbCameras)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(DeviceItem)
        QtCore.QMetaObject.connectSlotsByName(DeviceItem)

    def retranslateUi(self, DeviceItem):
        _translate = QtCore.QCoreApplication.translate
        DeviceItem.setWindowTitle(_translate("DeviceItem", "Form"))
        self.lbName.setText(_translate("DeviceItem", "[name]"))
        self.tbLogs.setToolTip(_translate("DeviceItem", "Show Logs"))
        self.tbLogs.setText(_translate("DeviceItem", "Show Logs"))
        self.tbCameras.setText(_translate("DeviceItem", "CAM"))

from experimental_control.devicecontrol.deviceimage import DeviceImage
from experimental_control.utils.clickablelabel import ClickableLabel
import beamline_console.gui.icons_rc
