# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/SnapshotWidget.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_SnapshotWidget(object):
    def setupUi(self, SnapshotWidget):
        SnapshotWidget.setObjectName("SnapshotWidget")
        SnapshotWidget.resize(639, 507)
        self.verticalLayout = QtWidgets.QVBoxLayout(SnapshotWidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tw_snapshots = QtWidgets.QTableWidget(SnapshotWidget)
        font = QtGui.QFont()
        font.setPointSize(18)
        font.setBold(False)
        font.setWeight(50)
        self.tw_snapshots.setFont(font)
        self.tw_snapshots.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tw_snapshots.setAlternatingRowColors(True)
        self.tw_snapshots.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tw_snapshots.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tw_snapshots.setObjectName("tw_snapshots")
        self.tw_snapshots.setColumnCount(0)
        self.tw_snapshots.setRowCount(0)
        self.tw_snapshots.verticalHeader().setDefaultSectionSize(100)
        self.tw_snapshots.verticalHeader().setMinimumSectionSize(100)
        self.verticalLayout.addWidget(self.tw_snapshots)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.but_apply = QtWidgets.QPushButton(SnapshotWidget)
        self.but_apply.setMinimumSize(QtCore.QSize(250, 75))
        self.but_apply.setMaximumSize(QtCore.QSize(16777215, 75))
        font = QtGui.QFont()
        font.setPointSize(20)
        font.setBold(False)
        font.setWeight(50)
        self.but_apply.setFont(font)
        self.but_apply.setObjectName("but_apply")
        self.horizontalLayout.addWidget(self.but_apply)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.but_delete = QtWidgets.QPushButton(SnapshotWidget)
        self.but_delete.setMinimumSize(QtCore.QSize(250, 75))
        font = QtGui.QFont()
        font.setPointSize(20)
        font.setBold(False)
        font.setWeight(50)
        self.but_delete.setFont(font)
        self.but_delete.setObjectName("but_delete")
        self.horizontalLayout.addWidget(self.but_delete)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.verticalLayout.setStretch(0, 1)

        self.retranslateUi(SnapshotWidget)
        QtCore.QMetaObject.connectSlotsByName(SnapshotWidget)

    def retranslateUi(self, SnapshotWidget):
        _translate = QtCore.QCoreApplication.translate
        SnapshotWidget.setWindowTitle(_translate("SnapshotWidget", "Form"))
        self.tw_snapshots.setSortingEnabled(True)
        self.but_apply.setText(_translate("SnapshotWidget", "Apply"))
        self.but_delete.setText(_translate("SnapshotWidget", "Delete"))

